# Contributing
Guidelines for contributing to this repository.

## Pre-commit
This repository uses pre-commit to enforce code style and formatting.
To install pre-commit, run the following command:
```bash
pip install pre-commit
```

To install the pre-commit hooks, which automatically runs pre-commit on every git commit, run the following command:
```bash
pre-commit install
```

To manually run the pre-commit hooks on all files, run the following command:
```bash
pre-commit run --all-files
```
